#!@@SH@@
#
# opkbuild
# src/ob-installplatconf
# Install build-time and run-time platform configuration files.
#
# Copyright (C) 2012 Patrick "P. J." McDermott
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

. '@@LIBOPKBUILD@@/load.sm'

ob_use locale
ob_use output
ob_use package

system_paths_ifs='
'

main()
{
	ob_set_text_domain 'opkbuild'

	ob_init_package '..'
	ob_parse_package_metadata -c '.opkbuild.cache'

	copied='false'

	if [ -r '../platconf' ]; then
		copy_config 'platconf' '.'
		copied='true'
	fi

	for pkg in ${OPK_PACKAGES}; do
		if [ -r "../${pkg}.pkg/platconf" ]; then
			copy_config "${pkg}.pkg/platconf" "${pkg}.data"
			copied='true'
		fi
	done

	"${copied}" || ob_info "$(ob_get_msg 'no_plat_config')"
}

copy_config()
{
	list="${1}"
	dest_base="${2}"

	while read -r src dest; do
		if [ -z "${src}" -o -z "${dest}" ]; then
			ob_error "$(ob_get_msg 'bad_config_syntax')" "${list}"
		fi

		# Make sure the destination directory exists.
		mkdir -p "${dest_base}/${dest%/*}" || \
			ob_error "$(ob_get_msg 'cant_make_config_dest_dir')" "${dest%/*}"

		# Find the config package files.
		src_base=''
		IFS="${system_paths_ifs}"
		for config_dir_base in $(ob_get_system_path 'platconf' \
				"${OPK_SOURCE}" "${OPK_SOURCE_VERSION}" "${OPK_HOST_PLAT}"); do
			unset IFS
			if [ -d "${config_dir_base}" ]; then
				src_base="${config_dir_base}"
			fi
		done
		unset IFS
		if [ -z "${src_base}" ]; then
			# This shouldn't happen unless the package maintainer neglected to
			# add the config package to the package's Build-Depends field.
			ob_error "$(ob_get_msg 'no_config_dir')"
		fi

		# Copy the config file(s).
		ob_info "$(ob_get_msg 'copying_config_file')" "${src}" "${dest}"
		cp -p "${src_base}/${src}" "${dest_base}/${dest}" || \
			ob_error "$(ob_get_msg 'cant_copy_config_file')"
	done <"../${list}"
}

main "${@}"
